/***************************************************/
/* CB_Type18.x  Criteria for SCDOT Drainage        */
/*                                                 */
/* Written By: Derricke Gray - Bentley Civil       */
/* Date: November, 2007                            */
/*                                                 */
/* Modified By: Dave Hoerner - Bentley             */
/* Date: July 2nd, 2008                            */
/*                                                 */
/***************************************************/

sub cb18
{
  /* INCLUDE SYMBOLOGY DEFINITIONS FROM SEPARATE CRITERIA FILE */
  include LevelSymbology.x
  
  /* SETUP THE RATIO IN ORDER TO SCALE CELLS CORRECTLY */
  _d_Ratio = HORIZONTAL TO VERTICAL SCALE RATIO
  
  /* DETERMINES WHICH SIDE THE STRUCTURE IS ON */
  draw skip to drainage component front point
  mark x100 y100
  draw skip to drainage component back point
  mark x101 y101
  if x101 > x100 then
    {
      _d_Side = 1  /* right side */
    }
  else
    {
      _d_Side = -1  /* left side */
    }

  /* FIND LARGEST PIPE SIZE TO DETERMINE BOX DIMENSIONS */
  _d_MaximumPipeSizeIn = Drainage Node Maximum Rise In
  _d_MaximumPipeSizeOut = Drainage Node Maximum Rise Out
  _d_LargestPipe = 0
  /* IF BOTH PIPES ARE DEFINED THEN CHECK WHICH ONE IS LARGER */
  if _d_MaximumPipeSizeOut < 1000 and _d_MaximumPipeSizeIn < 1000 then
    {
      /* CHECK TO SEE WHICH ONE IS LARGER */
      if _d_MaximumPipeSizeOut >= _d_MaximumPipeSizeIn then
        {
          _d_LargestPipe = _d_MaximumPipeSizeOut
        }
      else 
        {
          _d_LargestPipe = _d_MaximumPipeSizeIn
        }
    }
  /* ELSE CHECK TO SEE IF ONE IS DEFINED AND THE OTHER IS NOT */
  else if _d_MaximumPipeSizeOut < 1000 then
    {
      _d_LargestPipe = _d_MaximumPipeSizeOut
    }
  else if _d_MaximumPipeSizeIn < 1000 then
    {
      _d_LargestPipe = _d_MaximumPipeSizeIn
    }
  /* ELSE THEY ARE NEITHER DEFINED AND WE HAVE A PROBLEM */
  else
    {
      _d_LargestPipe = 999
    }
     
  if NOT (_d_LargestPipe = 999) then
  {
  /* POSITION POINTER AT FRONT OF CURB */
  draw skip to Drainage Component Front Point                           
  _d_DrainageNodeElevation = Drainage Node Elevation   mark x100 y100
  draw skip dx=0 dy=_d_DrainageNodeElevation - y100    mark x900 y900
   
  /* FIND INVERT ELEVATION OF STRUCTURE */
  _d_MinimumInvertElevation = Drainage Node Minimum Invert Elevation
  
  /* COMPUTE DEPTH OF STRUCTURE AND ADD 6" */
  _d_DepthOfStructure = _d_DrainageNodeElevation - _d_MinimumInvertElevation
  
  /* DRAW STRUCTURE BASED ON DEPTH */ 
  if _d_DepthOfStructure <= 12 then
    {  
      /* IF MAXIMUM PIPE SIZE IS LESS THEN 36" */
      if _d_LargestPipe <= 36/12 then
        {
        _d_D1 = 0
        _d_H1 = 0
        _d_FSA_Depth = 0
        _d_FSA_Width = 0
        _d_BoxWidth = 4.0
        _d_BoxLength = 4.0
        _d_PipeScale = _d_LargestPipe
        _d_PipeOffset = _d_BoxWidth / 2 
        
       set plot parameters "Structure Symbology"  
        draw skip dx=-_d_Side * .5/12 dy=-8/12                 mark x200 y200              
        draw dx=0 dy=-(_d_DepthOfStructure - 8/12)             mark x300 y300  mark x99 y99 
        draw dx=0 dy=-6/12                                     mark x400 y400                        
        draw dx=_d_Side * _d_BoxWidth dy=0                     mark x500 y500           
        draw dx=0 dy=1 to y200                                 mark x600 y600              
        draw to x200 y200
        
        /* DRAW TOP WALL THICKNESS - 8" */
        set plot parameters "Structure Wall Symbology"  
        draw skip to x200 y200
        draw dx=0 dy=8/12                                 
        draw dx=_d_Side dy=0 to x600                           
        draw dx=_d_Side * 5/12 dy=0                          mark x700 y700                          
        draw dx=0 dy=-1 to y600                                
        draw to x600 y600                                      
        
        /* DRAW BOTTOM WALL THICKNESS - 6" */
        draw skip to x400 y400
        draw dx=-_d_Side * 6/12 dy=0                           
        draw dx=0 dy=-6/12                                  
        draw dx=_d_Side dy=0 to x500
        draw dx=_d_Side * 6/12 dy=0                          
        draw dx=0 dy=1 to y500                              mark x800 y800
        draw to x500 y500
        
        /* PLACE PIPE SYMBOL */
        draw skip to x99 y99
        draw skip dx=_d_Side * _d_PipeOffset dy=0            mark x98 y98
        draw cell = XSPIPE
           xs  = _d_PipeScale
           ys  = _d_PipeScale * _d_Ratio
           "Structure Wall Symbology"   
            
        /* PLACE PIPE LABEL */
        draw skip to x98 y98
        draw skip dx=0 dy=_d_LargestPipe / 2
        _s_LargestPipe = cvt_d_s0(_d_LargestPipe * 12)
        _s_PipeLabel = _s_LargestPipe + ^"^ + " RC PIPE"
        draw text value=_s_PipeLabel "Structure Text Symbology" just=CC
        
        /* PLACE STATION LABEL */
        _s_Station = "STA. " + Drainage Node Station
        draw skip to x98 y98
        draw skip dx=0 dy=-2
        draw text value=_s_Station "Station Text Symbology" just=CT
        
        /**********************************************************************************/            
        /* PLACE STRUCTURE LABEL */
        draw skip to x98 y98
        draw skip dx=0 dy=(_d_DepthOfStructure / 2)+ 8/12
        draw text value = Drainage Node Library Item Name "Structure Text Symbology" just=CC
        draw skip to x98 y98
        draw skip dx=0 dy=(_d_DepthOfStructure / 2)
        draw text value = Drainage Node ID "Structure Text Symbology" just=CC
        draw skip to x98 y98
        draw skip dx=0 dy=(_d_DepthOfStructure / 2)- 8/12
        draw text value = Drainage Node Library Item Description "Structure Text Symbology" just=CC
        /**********************************************************************************/
        
        /* PLACE TOP ELEVATION LABEL */
        set plot parameters "Delimiter Line Symbology"
        draw skip to x700 y700
        draw skip dx=_d_Side * .25 dy=0                           
        draw dx=_d_Side * 2 dy=0
        draw skip dx=0 dy=.1
        _s_DrainageNodeElevation = "EL. " + cvt_d_s2(_d_DrainageNodeElevation)
        if _d_Side = 1 then 
          {
            draw text value=_s_DrainageNodeElevation "Structure Text Symbology" just=RB
          }
        else
          {
            draw text value=_s_DrainageNodeElevation "Structure Text Symbology" just=LB
          }
        
        /* PLACE BOTTOM INVERT ELEVATION LABEL */
        set plot parameters "Delimiter Line Symbology"
        draw skip to x98 y98
        draw skip dx=_d_Side * (_d_LargestPipe/2) dy=0            
        draw dx=_d_Side * 5 dy=0                                mark x701 y701
        draw skip dx=0 dy=.1
        _s_MinimumInvertElevation = "FL. " + cvt_d_s2(_d_MinimumInvertElevation)
        if _d_Side = 1 then
          {
            draw text value=_s_MinimumInvertElevation "Structure Text Symbology" just=RB
          }
        else
          {
            draw text value=_s_MinimumInvertElevation "Structure Text Symbology" just=LB
          }
        
        /* PLACE DEPTH OF STRUCTURE LABEL */
        set plot parameters "Delimiter Line Symbology"
        draw skip to x700 y700
        draw skip dx=_d_Side * .5 dy=0                           
        draw skip to x800 y800
        draw skip dx=_d_Side * .25 dy=0                           
        draw dx=_d_Side * .25 dy=0                              mark x901 y901
        draw dx=_d_Side * .25 dy=0
        draw skip to x901 y901
        /* Draw ArrowHead */
        draw dx=_d_Side * .1 dy=.3
        draw skip to x901 y901
        draw dx=-_d_Side * .1 dy=.3
        draw skip to x901 y901
        draw dx=0 dy=1 to y700                                   mark x900 y900
        /* Draw ArrowHead */
        draw dx=_d_Side * .1 dy=-.3
        draw skip to x900 y900
        draw dx=-_d_Side * .1 dy=-.3
        draw skip to x900 y900
        draw skip dx=_d_Side * .1 dy=(_d_DepthOfStructure / -2)
        _s_DepthOfStructure = cvt_d_s2(_d_DepthOfStructure + .5) + ^'^
        if _d_Side = 1 then
          {
            draw text value=_s_DepthOfStructure "Structure Text Symbology" just=CB angle=270
          }
        else
          {
            draw text value=_s_DepthOfStructure "Structure Text Symbology" just=CB angle=90
          }
        }
        
      /* ELSE IF MAXIMUM PIPE SIZE IS 42" OR 48" */
      else if _d_LargestPipe <= 48/12 then
        {
        _d_D1 = 72/12
        _d_H1 = 72/12
        _d_FSA_Depth = 8/12
        _d_FSA_Width = 84/12
        _d_PipeScale = _d_LargestPipe
        _d_H3 = (_d_DepthOfStructure + 6/12) - (_d_H1 + _d_FSA_Depth + "Wall Thickness")
        
        if _d_H3 >= 1.5 then /* DRAW 4X4 STD + FSA + BASE */
          {
          _d_BoxWidth = 4.0
          _d_BoxLength = 4.0
          _d_PipeOffset = _d_D1 / 2
          set plot parameters "Structure Symbology"         
          draw skip dx=-_d_Side * .5/12 dy=-"Wall Thickness"     mark x200 y200              
          draw dx=0 dy=-_d_H3                                    mark x300 y300              
          draw dx=_d_Side * _d_BoxWidth dy=0                     mark x400 y400              
          draw dx=0 dy=1 to y200                                 mark x500 y500              
          draw to x200 y200                                              
          
          set plot parameters "Structure Wall Symbology"         
          draw dx=0 dy=8/12
          draw dx=_d_side*(_d_BoxWidth + 6/12) dy=0							mark x705 y705
          draw dx=0 dy=-8/12
          draw dx=-_d_side*(6/12) dy =0
          draw skip to x200 y200
          set plot parameters "Structure Symbology"                
          draw skip to x300 y300
          draw dx=-_d_Side * (_d_FSA_Width - _d_BoxWidth)/2 dy=0   mark x600 y600
          draw dx=0 dy=-(_d_FSA_Depth)                             mark x601 y601
          draw dx=_d_Side * _d_FSA_Width dy=0                      mark x602 y602
          draw dx=0 dy=1 to y600                                   mark x603 y603
          draw dx=-_d_Side * (_d_FSA_Width - _d_BoxWidth)/2 dy=0 
        
          draw skip to x300 y300
          draw skip dx=0 dy=-(_d_FSA_Depth)         
          draw skip dx=-_d_Side * (_d_D1 - _d_BoxWidth)/2 dy=0   mark x700 y700
          draw dx=0 dy=-(_d_H1)                                  mark x701 y701 mark x99 y99
          draw dx=_d_Side * _d_D1 dy=0                           mark x703 y703
          draw dx=0 dy=1 to y700                                 mark x704 y704
          
          set plot parameters "Structure Wall Symbology"  
          draw skip to x701 y701
          draw dx=-_d_side*0.5 dy=0
          draw dx=0 dy=-0.5
          draw dx=_d_side*(_d_D1 + 1) dy=0
          draw dx=0 dy =0.5
          draw to x703 y703
                    
          /* DRAW WALL THICKNESS */
          /* draw skip to x200 y200
          draw skip dx=-_d_Side * "Wall Thickness" dy="Wall Thickness"  mark x800 y800
          draw skip to x300 y300
          draw skip dx=-_d_Side * "Wall Thickness" dy="Wall Thickness"  mark x801 y801
          draw skip to x600 y600
          draw skip dx=-_d_Side * "Wall Thickness" dy="Wall Thickness"  mark x802 y802
          draw skip to x700 y700
          draw skip dx=-_d_Side * "Wall Thickness" dy=-"Wall Thickness"  mark x803 y803
          draw skip to x800 y800
          draw to x801 y801
          draw to x802 y802
          draw dx=0 dy=-1 to y803
          draw to x803 y803 */
                    
          
          /* PLACE PIPE SYMBOL */
          draw skip to x99 y99
          draw skip dx=_d_Side * _d_PipeOffset dy=0.5             mark x98 y98
          draw cell = XSPIPE
             xs  = _d_PipeScale
             ys  = _d_PipeScale * _d_Ratio
             "Structure Symbology" 
        /* PLACE PIPE LABEL */
        draw skip to x98 y98
        draw skip dx=0 dy=_d_LargestPipe / 2
        _s_LargestPipe = cvt_d_s0(_d_LargestPipe * 12)
        _s_PipeLabel = _s_LargestPipe + ^"^ + " RC PIPE"
        draw text value=_s_PipeLabel "Structure Text Symbology" just=CC
        
        /* PLACE STATION LABEL */
        _s_Station = "STA. " + Drainage Node Station
        draw skip to x98 y98
        draw skip dx=0 dy=-2
        draw text value=_s_Station "Station Text Symbology" just=CT
        
        /**********************************************************************************/            
        /* PLACE STRUCTURE LABEL */
        draw skip to x98 y98
        draw skip dx=0 dy=(_d_DepthOfStructure / 2)+ 8/12
        draw text value = Drainage Node Library Item Name "Structure Text Symbology" just=CC
        draw skip to x98 y98
        draw skip dx=0 dy=(_d_DepthOfStructure / 2)
        draw text value = Drainage Node ID "Structure Text Symbology" just=CC
        draw skip to x98 y98
        draw skip dx=0 dy=(_d_DepthOfStructure / 2)- 8/12
        draw text value = Drainage Node Library Item Description "Structure Text Symbology" just=CC
        /**********************************************************************************/
        
        /* PLACE TOP ELEVATION LABEL */
        set plot parameters "Delimiter Line Symbology"
        draw skip to x705 y705
        draw skip dx=_d_Side * .25 dy=0            mark x706 y706               
        draw dx=_d_Side * 2 dy=0
        draw skip dx=0 dy=.1
        _s_DrainageNodeElevation = "EL. " + cvt_d_s2(_d_DrainageNodeElevation)
        if _d_Side = 1 then 
          {
            draw text value=_s_DrainageNodeElevation "Structure Text Symbology" just=RB
          }
        else
          {
            draw text value=_s_DrainageNodeElevation "Structure Text Symbology" just=LB
          }
        
        /* PLACE BOTTOM INVERT ELEVATION LABEL */
        set plot parameters "Delimiter Line Symbology"
        draw skip to x98 y98
        draw skip dx=_d_Side * (_d_LargestPipe/2) dy=0            
        draw dx=_d_Side * 5 dy=0                                mark x707 y707
        draw skip dx=0 dy=.1
        _s_MinimumInvertElevation = "FL. " + cvt_d_s2(_d_MinimumInvertElevation)
        if _d_Side = 1 then
          {
            draw text value=_s_MinimumInvertElevation "Structure Text Symbology" just=RB
          }
        else
          {
            draw text value=_s_MinimumInvertElevation "Structure Text Symbology" just=LB
          }
        
        /* PLACE DEPTH OF STRUCTURE LABEL */
        set plot parameters "Delimiter Line Symbology"
        draw skip to x705 y705
        draw skip dx=_d_Side * .5 dy=0                 mark x706 y706          
        draw skip to x703 y703
        draw skip dx=_d_Side * .5 dy=0                           
        draw dx=_d_Side * .25 dy=0                              mark x901 y901
        draw dx=_d_Side * .25 dy=0
        draw skip to x901 y901
        /* Draw ArrowHead */
        draw dx=_d_Side * .1 dy=.3
        draw skip to x901 y901
        draw dx=-_d_Side * .1 dy=.3
        draw skip to x901 y901
        draw dx=0 dy=1 to y706                                   mark x900 y900
        /* Draw ArrowHead */
        draw dx=_d_Side * .1 dy=-.3
        draw skip to x900 y900
        draw dx=-_d_Side * .1 dy=-.3
        draw skip to x900 y900
        draw skip dx=_d_Side * .1 dy=(_d_DepthOfStructure / -2)
        _s_DepthOfStructure = cvt_d_s2(_d_DepthOfStructure + .5) + ^'^
        if _d_Side = 1 then
          {
            draw text value=_s_DepthOfStructure "Structure Text Symbology" just=CB angle=270
          }
        else
          {
            draw text value=_s_DepthOfStructure "Structure Text Symbology" just=CB angle=90
          }
          }
          else /* DRAW 10X10 */
          {
            _d_BoxWidth = 10.0
            _d_BoxLength = 10.0
            _d_PipeOffset = _d_BoxWidth / 2
            set plot parameters "Special Structure Symbology"  
            mark x200 y200              
            draw dx=0 dy=-(_d_DepthOfStructure + 0.5) /*depth of structure plus t1*/
            mark x300 y300 mark x99 y99 
            /*mark x400 y400  */                      
            draw dx=_d_Side * _d_BoxWidth dy=0                      mark x500 y500             
            draw dx=0 dy=1 to y200                                  mark x600 y600              
            draw to x200 y200 
            
            /* DRAW WALL THICKNESS 
            draw skip to x200 y200
            draw skip dx=-_d_Side * "Wall Thickness" dy="Wall Thickness"  mark x700 y700
            draw dx=0 dy=-1 to y400
            draw dx=0 dy=-"Wall Thickness"
            draw dx=_d_Side dy=0 to x500
            draw dx=_d_Side * "Wall Thickness" dy=0
            draw dx=0 dy=1 to y700
            draw to x700 y700 */
            
          
            /* PLACE PIPE SYMBOL */
            draw skip to x99 y99
            draw skip dx=_d_Side * _d_PipeOffset dy=0 
            draw skip dx=0 dy=0.5       mark x98 y98
            draw cell = XSPIPE
             xs  = _d_PipeScale
             ys  = _d_PipeScale * _d_Ratio
             "Structure Symbology" 

            /* PLACE STRUCTURE LABEL */
            draw skip to x98 y98
            draw skip dx=0 dy=-1
            _s_BoxWidth = cvt_d_s1(_d_BoxWidth)
            _s_BoxLength = cvt_d_s1(_d_BoxLength)
            _s_const = Drainage Node Library Item Name + " with Mod. Box. Special Design Required"
            draw text value=_s_const "Structure Text Symbology"
        /* PLACE TOP ELEVATION LABEL */
        set plot parameters "Delimiter Line Symbology"
        draw skip to x600 y600
        draw skip dx=_d_Side * .25 dy=0            mark x606 y606               
        draw dx=_d_Side * 2 dy=0
        draw skip dx=0 dy=.1
        _s_DrainageNodeElevation = "EL. " + cvt_d_s2(_d_DrainageNodeElevation)
        if _d_Side = 1 then 
          {
            draw text value=_s_DrainageNodeElevation "Structure Text Symbology" just=RB
          }
        else
          {
            draw text value=_s_DrainageNodeElevation "Structure Text Symbology" just=LB
          }
        
        /* PLACE BOTTOM INVERT ELEVATION LABEL */
        set plot parameters "Delimiter Line Symbology"
        draw skip to x98 y98
        draw skip dx=_d_Side * (_d_LargestPipe/2) dy=0            
        draw dx=_d_Side * (_d_boxwidth/2 + 2) dy=0                                mark x607 y607
        draw skip dx=0 dy=.1
        _s_MinimumInvertElevation = "FL. " + cvt_d_s2(_d_MinimumInvertElevation)
        if _d_Side = 1 then
          {
            draw text value=_s_MinimumInvertElevation "Structure Text Symbology" just=RB
          }
        else
          {
            draw text value=_s_MinimumInvertElevation "Structure Text Symbology" just=LB
          }
        
        /* PLACE DEPTH OF STRUCTURE LABEL */
        set plot parameters "Delimiter Line Symbology"
        draw skip to x600 y600
        draw skip dx=_d_Side * .5 dy=0                 mark x606 y606          
        draw skip to x500 y500
        draw skip dx=_d_Side * .5 dy=0                           
        draw dx=_d_Side * .25 dy=0                              mark x901 y901
        draw dx=_d_Side * .25 dy=0
        draw skip to x901 y901
        /* Draw ArrowHead */
        draw dx=_d_Side * .1 dy=.3
        draw skip to x901 y901
        draw dx=-_d_Side * .1 dy=.3
        draw skip to x901 y901
        draw dx=0 dy=1 to y606                                   mark x900 y900
        /* Draw ArrowHead */
        draw dx=_d_Side * .1 dy=-.3
        draw skip to x900 y900
        draw dx=-_d_Side * .1 dy=-.3
        draw skip to x900 y900
        draw skip dx=_d_Side * .1 dy=(_d_DepthOfStructure / -2)
        _s_DepthOfStructure = cvt_d_s2(_d_DepthOfStructure + .5) + ^'^
        if _d_Side = 1 then
          {
            draw text value=_s_DepthOfStructure "Structure Text Symbology" just=CB angle=270
          }
        else
          {
            draw text value=_s_DepthOfStructure "Structure Text Symbology" just=CB angle=90
          }
          }        
        }
      /* ELSE IF MAXIMUM PIPE SIZE IS 54" */
      else if _d_LargestPipe <= 54/12 then
        {
        _d_D1 = 84/12
        _d_H1 = 80/12
        _d_FSA_Depth = 8/12
        _d_FSA_Width = 98/12
        _d_PipeScale = _d_LargestPipe
        _d_H3 = (_d_DepthOfStructure + 6/12) - (_d_H1 + _d_FSA_Depth + "Wall Thickness")

        if _d_H3 >= 1.5 then /* DRAW 4X4 STD + FSA + BASE */
          {
          _d_BoxWidth = 4.0
          _d_BoxLength = 4.0
          _d_PipeOffset = _d_D1 / 2

          set plot parameters "Structure Symbology"         
          draw skip dx=-_d_Side * .5/12 dy=-"Wall Thickness"     mark x200 y200              
          draw dx=0 dy=-_d_H3                                    mark x300 y300              
          draw dx=_d_Side * _d_BoxWidth dy=0                     mark x400 y400              
          draw dx=0 dy=1 to y200                                 mark x500 y500              
          draw to x200 y200                                              
          
          set plot parameters "Structure Wall Symbology"         
          draw dx=0 dy=8/12
          draw dx=_d_side*(_d_BoxWidth + 6/12) dy=0							mark x705 y705
          draw dx=0 dy=-8/12
          draw dx=-_d_side*(6/12) dy =0
          draw skip to x200 y200
          set plot parameters "Structure Symbology"                
          draw skip to x300 y300
          draw dx=-_d_Side * (_d_FSA_Width - _d_BoxWidth)/2 dy=0   mark x600 y600
          draw dx=0 dy=-(_d_FSA_Depth)                             mark x601 y601
          draw dx=_d_Side * _d_FSA_Width dy=0                      mark x602 y602
          draw dx=0 dy=1 to y600                                   mark x603 y603
          draw dx=-_d_Side * (_d_FSA_Width - _d_BoxWidth)/2 dy=0 
        
          draw skip to x300 y300
          draw skip dx=0 dy=-(_d_FSA_Depth)         
          draw skip dx=-_d_Side * (_d_D1 - _d_BoxWidth)/2 dy=0   mark x700 y700
          draw dx=0 dy=-(_d_H1)                                  mark x701 y701 mark x99 y99
          draw dx=_d_Side * _d_D1 dy=0                           mark x703 y703
          draw dx=0 dy=1 to y700                                 mark x704 y704
          
          set plot parameters "Structure Wall Symbology"  
          draw skip to x701 y701
          draw dx=-_d_side*0.5 dy=0
          draw dx=0 dy=-0.5
          draw dx=_d_side*(_d_D1 + 1) dy=0
          draw dx=0 dy =0.5
          draw to x703 y703
                    
          /* DRAW WALL THICKNESS */
          /* draw skip to x200 y200
          draw skip dx=-_d_Side * "Wall Thickness" dy="Wall Thickness"  mark x800 y800
          draw skip to x300 y300
          draw skip dx=-_d_Side * "Wall Thickness" dy="Wall Thickness"  mark x801 y801
          draw skip to x600 y600
          draw skip dx=-_d_Side * "Wall Thickness" dy="Wall Thickness"  mark x802 y802
          draw skip to x700 y700
          draw skip dx=-_d_Side * "Wall Thickness" dy=-"Wall Thickness"  mark x803 y803
          draw skip to x800 y800
          draw to x801 y801
          draw to x802 y802
          draw dx=0 dy=-1 to y803
          draw to x803 y803 */
                    
          
          /* PLACE PIPE SYMBOL */
          draw skip to x99 y99
          draw skip dx=_d_Side * _d_PipeOffset dy=0.5             mark x98 y98
          draw cell = XSPIPE
             xs  = _d_PipeScale
             ys  = _d_PipeScale * _d_Ratio
             "Structure Symbology" 
        /* PLACE PIPE LABEL */
        draw skip to x98 y98
        draw skip dx=0 dy=_d_LargestPipe / 2
        _s_LargestPipe = cvt_d_s0(_d_LargestPipe * 12)
        _s_PipeLabel = _s_LargestPipe + ^"^ + " RC PIPE"
        draw text value=_s_PipeLabel "Structure Text Symbology" just=CC
        
        /* PLACE STATION LABEL */
        _s_Station = "STA. " + Drainage Node Station
        draw skip to x98 y98
        draw skip dx=0 dy=-2
        draw text value=_s_Station "Station Text Symbology" just=CT
        
        /**********************************************************************************/            
        /* PLACE STRUCTURE LABEL */
        draw skip to x98 y98
        draw skip dx=0 dy=(_d_DepthOfStructure / 2)+ 8/12
        draw text value = Drainage Node Library Item Name "Structure Text Symbology" just=CC
        draw skip to x98 y98
        draw skip dx=0 dy=(_d_DepthOfStructure / 2)
        draw text value = Drainage Node ID "Structure Text Symbology" just=CC
        draw skip to x98 y98
        draw skip dx=0 dy=(_d_DepthOfStructure / 2)- 8/12
        draw text value = Drainage Node Library Item Description "Structure Text Symbology" just=CC
        /**********************************************************************************/
        
        /* PLACE TOP ELEVATION LABEL */
        set plot parameters "Delimiter Line Symbology"
        draw skip to x705 y705
        draw skip dx=_d_Side * .25 dy=0            mark x706 y706               
        draw dx=_d_Side * 2 dy=0
        draw skip dx=0 dy=.1
        _s_DrainageNodeElevation = "EL. " + cvt_d_s2(_d_DrainageNodeElevation)
        if _d_Side = 1 then 
          {
            draw text value=_s_DrainageNodeElevation "Structure Text Symbology" just=RB
          }
        else
          {
            draw text value=_s_DrainageNodeElevation "Structure Text Symbology" just=LB
          }
        
        /* PLACE BOTTOM INVERT ELEVATION LABEL */
        set plot parameters "Delimiter Line Symbology"
        draw skip to x98 y98
        draw skip dx=_d_Side * (_d_LargestPipe/2) dy=0            
        draw dx=_d_Side * 5 dy=0                                mark x707 y707
        draw skip dx=0 dy=.1
        _s_MinimumInvertElevation = "FL. " + cvt_d_s2(_d_MinimumInvertElevation)
        if _d_Side = 1 then
          {
            draw text value=_s_MinimumInvertElevation "Structure Text Symbology" just=RB
          }
        else
          {
            draw text value=_s_MinimumInvertElevation "Structure Text Symbology" just=LB
          }
        
        /* PLACE DEPTH OF STRUCTURE LABEL */
        set plot parameters "Delimiter Line Symbology"
        draw skip to x705 y705
        draw skip dx=_d_Side * .5 dy=0                 mark x706 y706          
        draw skip to x703 y703
        draw skip dx=_d_Side * .5 dy=0                           
        draw dx=_d_Side * .25 dy=0                              mark x901 y901
        draw dx=_d_Side * .25 dy=0
        draw skip to x901 y901
        /* Draw ArrowHead */
        draw dx=_d_Side * .1 dy=.3
        draw skip to x901 y901
        draw dx=-_d_Side * .1 dy=.3
        draw skip to x901 y901
        draw dx=0 dy=1 to y706                                   mark x900 y900
        /* Draw ArrowHead */
        draw dx=_d_Side * .1 dy=-.3
        draw skip to x900 y900
        draw dx=-_d_Side * .1 dy=-.3
        draw skip to x900 y900
        draw skip dx=_d_Side * .1 dy=(_d_DepthOfStructure / -2)
        _s_DepthOfStructure = cvt_d_s2(_d_DepthOfStructure + .5) + ^'^
        if _d_Side = 1 then
          {
            draw text value=_s_DepthOfStructure "Structure Text Symbology" just=CB angle=270
          }
        else
          {
            draw text value=_s_DepthOfStructure "Structure Text Symbology" just=CB angle=90
          }
          }
          else /* DRAW 10X10 */
          {
            _d_BoxWidth = 10.0
            _d_BoxLength = 10.0
            _d_PipeOffset = _d_BoxWidth / 2

            set plot parameters "Special Structure Symbology"  
            mark x200 y200              
            draw dx=0 dy=-(_d_DepthOfStructure + 0.5) /*depth of structure plus t1*/
            mark x300 y300 mark x99 y99 
            /*mark x400 y400  */                      
            draw dx=_d_Side * _d_BoxWidth dy=0                      mark x500 y500             
            draw dx=0 dy=1 to y200                                  mark x600 y600              
            draw to x200 y200 
            
            /* DRAW WALL THICKNESS 
            draw skip to x200 y200
            draw skip dx=-_d_Side * "Wall Thickness" dy="Wall Thickness"  mark x700 y700
            draw dx=0 dy=-1 to y400
            draw dx=0 dy=-"Wall Thickness"
            draw dx=_d_Side dy=0 to x500
            draw dx=_d_Side * "Wall Thickness" dy=0
            draw dx=0 dy=1 to y700
            draw to x700 y700 */
            
    
            /* PLACE PIPE SYMBOL */
            draw skip to x99 y99
            draw skip dx=_d_Side * _d_PipeOffset dy=0 
            draw skip dx=0 dy=0.5       mark x98 y98
            draw cell = XSPIPE
             xs  = _d_PipeScale
             ys  = _d_PipeScale * _d_Ratio
             "Structure Symbology" 

            /* PLACE STRUCTURE LABEL */
            draw skip to x98 y98
            draw skip dx=0 dy=-1
            _s_BoxWidth = cvt_d_s1(_d_BoxWidth)
            _s_BoxLength = cvt_d_s1(_d_BoxLength)
            _s_const = Drainage Node Library Item Name + " with Mod. Box. Special Design Required"
            draw text value=_s_const "Structure Text Symbology"
        /* PLACE TOP ELEVATION LABEL */
        set plot parameters "Delimiter Line Symbology"
        draw skip to x600 y600
        draw skip dx=_d_Side * .25 dy=0            mark x606 y606               
        draw dx=_d_Side * 2 dy=0
        draw skip dx=0 dy=.1
        _s_DrainageNodeElevation = "EL. " + cvt_d_s2(_d_DrainageNodeElevation)
        if _d_Side = 1 then 
          {
            draw text value=_s_DrainageNodeElevation "Structure Text Symbology" just=RB
          }
        else
          {
            draw text value=_s_DrainageNodeElevation "Structure Text Symbology" just=LB
          }
        
        /* PLACE BOTTOM INVERT ELEVATION LABEL */
        set plot parameters "Delimiter Line Symbology"
        draw skip to x98 y98
        draw skip dx=_d_Side * (_d_LargestPipe/2) dy=0            
        draw dx=_d_Side * (_d_boxwidth/2 + 2) dy=0                                mark x607 y607
        draw skip dx=0 dy=.1
        _s_MinimumInvertElevation = "FL. " + cvt_d_s2(_d_MinimumInvertElevation)
        if _d_Side = 1 then
          {
            draw text value=_s_MinimumInvertElevation "Structure Text Symbology" just=RB
          }
        else
          {
            draw text value=_s_MinimumInvertElevation "Structure Text Symbology" just=LB
          }
        
        /* PLACE DEPTH OF STRUCTURE LABEL */
        set plot parameters "Delimiter Line Symbology"
        draw skip to x600 y600
        draw skip dx=_d_Side * .5 dy=0                 mark x606 y606          
        draw skip to x500 y500
        draw skip dx=_d_Side * .5 dy=0                           
        draw dx=_d_Side * .25 dy=0                              mark x901 y901
        draw dx=_d_Side * .25 dy=0
        draw skip to x901 y901
        /* Draw ArrowHead */
        draw dx=_d_Side * .1 dy=.3
        draw skip to x901 y901
        draw dx=-_d_Side * .1 dy=.3
        draw skip to x901 y901
        draw dx=0 dy=1 to y606                                   mark x900 y900
        /* Draw ArrowHead */
        draw dx=_d_Side * .1 dy=-.3
        draw skip to x900 y900
        draw dx=-_d_Side * .1 dy=-.3
        draw skip to x900 y900
        draw skip dx=_d_Side * .1 dy=(_d_DepthOfStructure / -2)
        _s_DepthOfStructure = cvt_d_s2(_d_DepthOfStructure + .5) + ^'^
        if _d_Side = 1 then
          {
            draw text value=_s_DepthOfStructure "Structure Text Symbology" just=CB angle=270
          }
        else
          {
            draw text value=_s_DepthOfStructure "Structure Text Symbology" just=CB angle=90
          }
          }                
        }
      /* ELSE IF MAXIMUM PIPE SIZE IS 60" */
      else if _d_LargestPipe <= 60/12 then
        {
        _d_D1 = 96/12
        _d_H1 = 88/12
        _d_FSA_Depth = 9/12
        _d_FSA_Width = 112/12
        _d_PipeScale = _d_LargestPipe
        _d_H3 = (_d_DepthOfStructure + 6/12) - (_d_H1 + _d_FSA_Depth + "Wall Thickness")

        if _d_H3 >= 1.5 then /* DRAW 4X4 STD + FSA + BASE */
          {
          _d_BoxWidth = 4.0
          _d_BoxLength = 4.0
          _d_PipeOffset = _d_D1 / 2

          set plot parameters "Structure Symbology"         
          draw skip dx=-_d_Side * .5/12 dy=-"Wall Thickness"     mark x200 y200              
          draw dx=0 dy=-_d_H3                                    mark x300 y300              
          draw dx=_d_Side * _d_BoxWidth dy=0                     mark x400 y400              
          draw dx=0 dy=1 to y200                                 mark x500 y500              
          draw to x200 y200                                              
          
          set plot parameters "Structure Wall Symbology"         
          draw dx=0 dy=8/12
          draw dx=_d_side*(_d_BoxWidth + 6/12) dy=0							mark x705 y705
          draw dx=0 dy=-8/12
          draw dx=-_d_side*(6/12) dy =0
          draw skip to x200 y200
          set plot parameters "Structure Symbology"                
          draw skip to x300 y300
          draw dx=-_d_Side * (_d_FSA_Width - _d_BoxWidth)/2 dy=0   mark x600 y600
          draw dx=0 dy=-(_d_FSA_Depth)                             mark x601 y601
          draw dx=_d_Side * _d_FSA_Width dy=0                      mark x602 y602
          draw dx=0 dy=1 to y600                                   mark x603 y603
          draw dx=-_d_Side * (_d_FSA_Width - _d_BoxWidth)/2 dy=0 
        
          draw skip to x300 y300
          draw skip dx=0 dy=-(_d_FSA_Depth)         
          draw skip dx=-_d_Side * (_d_D1 - _d_BoxWidth)/2 dy=0   mark x700 y700
          draw dx=0 dy=-(_d_H1)                                  mark x701 y701 mark x99 y99
          draw dx=_d_Side * _d_D1 dy=0                           mark x703 y703
          draw dx=0 dy=1 to y700                                 mark x704 y704
          
          set plot parameters "Structure Wall Symbology"  
          draw skip to x701 y701
          draw dx=-_d_side*0.5 dy=0
          draw dx=0 dy=-0.5
          draw dx=_d_side*(_d_D1 + 1) dy=0
          draw dx=0 dy =0.5
          draw to x703 y703
                    
          /* DRAW WALL THICKNESS */
          /* draw skip to x200 y200
          draw skip dx=-_d_Side * "Wall Thickness" dy="Wall Thickness"  mark x800 y800
          draw skip to x300 y300
          draw skip dx=-_d_Side * "Wall Thickness" dy="Wall Thickness"  mark x801 y801
          draw skip to x600 y600
          draw skip dx=-_d_Side * "Wall Thickness" dy="Wall Thickness"  mark x802 y802
          draw skip to x700 y700
          draw skip dx=-_d_Side * "Wall Thickness" dy=-"Wall Thickness"  mark x803 y803
          draw skip to x800 y800
          draw to x801 y801
          draw to x802 y802
          draw dx=0 dy=-1 to y803
          draw to x803 y803 */
                    
          
          /* PLACE PIPE SYMBOL */
          draw skip to x99 y99
          draw skip dx=_d_Side * _d_PipeOffset dy=0.5             mark x98 y98
          draw cell = XSPIPE
             xs  = _d_PipeScale
             ys  = _d_PipeScale * _d_Ratio
             "Structure Symbology" 
        /* PLACE PIPE LABEL */
        draw skip to x98 y98
        draw skip dx=0 dy=_d_LargestPipe / 2
        _s_LargestPipe = cvt_d_s0(_d_LargestPipe * 12)
        _s_PipeLabel = _s_LargestPipe + ^"^ + " RC PIPE"
        draw text value=_s_PipeLabel "Structure Text Symbology" just=CC
        
        /* PLACE STATION LABEL */
        _s_Station = "STA. " + Drainage Node Station
        draw skip to x98 y98
        draw skip dx=0 dy=-2
        draw text value=_s_Station "Station Text Symbology" just=CT
        
        /**********************************************************************************/            
        /* PLACE STRUCTURE LABEL */
        draw skip to x98 y98
        draw skip dx=0 dy=(_d_DepthOfStructure / 2)+ 8/12
        draw text value = Drainage Node Library Item Name "Structure Text Symbology" just=CC
        draw skip to x98 y98
        draw skip dx=0 dy=(_d_DepthOfStructure / 2)
        draw text value = Drainage Node ID "Structure Text Symbology" just=CC
        draw skip to x98 y98
        draw skip dx=0 dy=(_d_DepthOfStructure / 2)- 8/12
        draw text value = Drainage Node Library Item Description "Structure Text Symbology" just=CC
        /**********************************************************************************/
        
        /* PLACE TOP ELEVATION LABEL */
        set plot parameters "Delimiter Line Symbology"
        draw skip to x705 y705
        draw skip dx=_d_Side * .25 dy=0            mark x706 y706               
        draw dx=_d_Side * 2 dy=0
        draw skip dx=0 dy=.1
        _s_DrainageNodeElevation = "EL. " + cvt_d_s2(_d_DrainageNodeElevation)
        if _d_Side = 1 then 
          {
            draw text value=_s_DrainageNodeElevation "Structure Text Symbology" just=RB
          }
        else
          {
            draw text value=_s_DrainageNodeElevation "Structure Text Symbology" just=LB
          }
        
        /* PLACE BOTTOM INVERT ELEVATION LABEL */
        set plot parameters "Delimiter Line Symbology"
        draw skip to x98 y98
        draw skip dx=_d_Side * (_d_LargestPipe/2) dy=0            
        draw dx=_d_Side * 5 dy=0                                mark x707 y707
        draw skip dx=0 dy=.1
        _s_MinimumInvertElevation = "FL. " + cvt_d_s2(_d_MinimumInvertElevation)
        if _d_Side = 1 then
          {
            draw text value=_s_MinimumInvertElevation "Structure Text Symbology" just=RB
          }
        else
          {
            draw text value=_s_MinimumInvertElevation "Structure Text Symbology" just=LB
          }
        
        /* PLACE DEPTH OF STRUCTURE LABEL */
        set plot parameters "Delimiter Line Symbology"
        draw skip to x705 y705
        draw skip dx=_d_Side * .5 dy=0                 mark x706 y706          
        draw skip to x703 y703
        draw skip dx=_d_Side * .5 dy=0                           
        draw dx=_d_Side * .25 dy=0                              mark x901 y901
        draw dx=_d_Side * .25 dy=0
        draw skip to x901 y901
        /* Draw ArrowHead */
        draw dx=_d_Side * .1 dy=.3
        draw skip to x901 y901
        draw dx=-_d_Side * .1 dy=.3
        draw skip to x901 y901
        draw dx=0 dy=1 to y706                                   mark x900 y900
        /* Draw ArrowHead */
        draw dx=_d_Side * .1 dy=-.3
        draw skip to x900 y900
        draw dx=-_d_Side * .1 dy=-.3
        draw skip to x900 y900
        draw skip dx=_d_Side * .1 dy=(_d_DepthOfStructure / -2)
        _s_DepthOfStructure = cvt_d_s2(_d_DepthOfStructure + .5) + ^'^
        if _d_Side = 1 then
          {
            draw text value=_s_DepthOfStructure "Structure Text Symbology" just=CB angle=270
          }
        else
          {
            draw text value=_s_DepthOfStructure "Structure Text Symbology" just=CB angle=90
          }
          }
          else /* DRAW 10X10 */
          {
            _d_BoxWidth = 10.0
            _d_BoxLength = 10.0
            _d_PipeOffset = _d_BoxWidth / 2

            set plot parameters "Special Structure Symbology"  
            mark x200 y200              
            draw dx=0 dy=-(_d_DepthOfStructure + 0.5) /*depth of structure plus t1*/
            mark x300 y300 mark x99 y99 
            /*mark x400 y400  */                      
            draw dx=_d_Side * _d_BoxWidth dy=0                      mark x500 y500             
            draw dx=0 dy=1 to y200                                  mark x600 y600              
            draw to x200 y200 
            
            /* DRAW WALL THICKNESS 
            draw skip to x200 y200
            draw skip dx=-_d_Side * "Wall Thickness" dy="Wall Thickness"  mark x700 y700
            draw dx=0 dy=-1 to y400
            draw dx=0 dy=-"Wall Thickness"
            draw dx=_d_Side dy=0 to x500
            draw dx=_d_Side * "Wall Thickness" dy=0
            draw dx=0 dy=1 to y700
            draw to x700 y700 */
            
          
            /* PLACE PIPE SYMBOL */
            draw skip to x99 y99
            draw skip dx=_d_Side * _d_PipeOffset dy=0 
            draw skip dx=0 dy=0.5       mark x98 y98
            draw cell = XSPIPE
             xs  = _d_PipeScale
             ys  = _d_PipeScale * _d_Ratio
             "Structure Symbology" 

            /* PLACE STRUCTURE LABEL */
            draw skip to x98 y98
            draw skip dx=0 dy=-1
            _s_BoxWidth = cvt_d_s1(_d_BoxWidth)
            _s_BoxLength = cvt_d_s1(_d_BoxLength)
            _s_const = Drainage Node Library Item Name + " with Mod. Box. Special Design Required"
            draw text value=_s_const "Structure Text Symbology"
        /* PLACE TOP ELEVATION LABEL */
        set plot parameters "Delimiter Line Symbology"
        draw skip to x600 y600
        draw skip dx=_d_Side * .25 dy=0            mark x606 y606               
        draw dx=_d_Side * 2 dy=0
        draw skip dx=0 dy=.1
        _s_DrainageNodeElevation = "EL. " + cvt_d_s2(_d_DrainageNodeElevation)
        if _d_Side = 1 then 
          {
            draw text value=_s_DrainageNodeElevation "Structure Text Symbology" just=RB
          }
        else
          {
            draw text value=_s_DrainageNodeElevation "Structure Text Symbology" just=LB
          }
        
        /* PLACE BOTTOM INVERT ELEVATION LABEL */
        set plot parameters "Delimiter Line Symbology"
        draw skip to x98 y98
        draw skip dx=_d_Side * (_d_LargestPipe/2) dy=0            
        draw dx=_d_Side * (_d_boxwidth/2 + 2) dy=0                                mark x607 y607
        draw skip dx=0 dy=.1
        _s_MinimumInvertElevation = "FL. " + cvt_d_s2(_d_MinimumInvertElevation)
        if _d_Side = 1 then
          {
            draw text value=_s_MinimumInvertElevation "Structure Text Symbology" just=RB
          }
        else
          {
            draw text value=_s_MinimumInvertElevation "Structure Text Symbology" just=LB
          }
        
        /* PLACE DEPTH OF STRUCTURE LABEL */
        set plot parameters "Delimiter Line Symbology"
        draw skip to x600 y600
        draw skip dx=_d_Side * .5 dy=0                 mark x606 y606          
        draw skip to x500 y500
        draw skip dx=_d_Side * .5 dy=0                           
        draw dx=_d_Side * .25 dy=0                              mark x901 y901
        draw dx=_d_Side * .25 dy=0
        draw skip to x901 y901
        /* Draw ArrowHead */
        draw dx=_d_Side * .1 dy=.3
        draw skip to x901 y901
        draw dx=-_d_Side * .1 dy=.3
        draw skip to x901 y901
        draw dx=0 dy=1 to y606                                   mark x900 y900
        /* Draw ArrowHead */
        draw dx=_d_Side * .1 dy=-.3
        draw skip to x900 y900
        draw dx=-_d_Side * .1 dy=-.3
        draw skip to x900 y900
        draw skip dx=_d_Side * .1 dy=(_d_DepthOfStructure / -2)
        _s_DepthOfStructure = cvt_d_s2(_d_DepthOfStructure + .5) + ^'^
        if _d_Side = 1 then
          {
            draw text value=_s_DepthOfStructure "Structure Text Symbology" just=CB angle=270
          }
        else
          {
            draw text value=_s_DepthOfStructure "Structure Text Symbology" just=CB angle=90
          }
          }                
        }
      /* ELSE IF MAXIMUM PIPE SIZE IS 66" */
      else if _d_LargestPipe <= 66/12 then
        {
        _d_D1 = 120/12
        _d_H1 = 96/12
        _d_FSA_Depth = 10/12
        _d_FSA_Width = 140/12
        _d_PipeScale = _d_LargestPipe
        _d_H3 = (_d_DepthOfStructure + 6/12) - (_d_H1 + _d_FSA_Depth + "Wall Thickness")
        
        if _d_H3 >= 1.5 then /* DRAW 4X4 STD + FSA + BASE */
          {
          _d_BoxWidth = 4.0
          _d_BoxLength = 4.0
          _d_PipeOffset = _d_D1 / 2

          set plot parameters "Structure Symbology"         
          draw skip dx=-_d_Side * .5/12 dy=-"Wall Thickness"     mark x200 y200              
          draw dx=0 dy=-_d_H3                                    mark x300 y300              
          draw dx=_d_Side * _d_BoxWidth dy=0                     mark x400 y400              
          draw dx=0 dy=1 to y200                                 mark x500 y500              
          draw to x200 y200                                              
          
          set plot parameters "Structure Wall Symbology"         
          draw dx=0 dy=8/12
          draw dx=_d_side*(_d_BoxWidth + 6/12) dy=0							mark x705 y705
          draw dx=0 dy=-8/12
          draw dx=-_d_side*(6/12) dy =0
          draw skip to x200 y200
          set plot parameters "Structure Symbology"                
          draw skip to x300 y300
          draw dx=-_d_Side * (_d_FSA_Width - _d_BoxWidth)/2 dy=0   mark x600 y600
          draw dx=0 dy=-(_d_FSA_Depth)                             mark x601 y601
          draw dx=_d_Side * _d_FSA_Width dy=0                      mark x602 y602
          draw dx=0 dy=1 to y600                                   mark x603 y603
          draw dx=-_d_Side * (_d_FSA_Width - _d_BoxWidth)/2 dy=0 
        
          draw skip to x300 y300
          draw skip dx=0 dy=-(_d_FSA_Depth)         
          draw skip dx=-_d_Side * (_d_D1 - _d_BoxWidth)/2 dy=0   mark x700 y700
          draw dx=0 dy=-(_d_H1)                                  mark x701 y701 mark x99 y99
          draw dx=_d_Side * _d_D1 dy=0                           mark x703 y703
          draw dx=0 dy=1 to y700                                 mark x704 y704
          
          set plot parameters "Structure Wall Symbology"  
          draw skip to x701 y701
          draw dx=-_d_side*0.5 dy=0
          draw dx=0 dy=-0.5
          draw dx=_d_side*(_d_D1 + 1) dy=0
          draw dx=0 dy =0.5
          draw to x703 y703
                    
          /* DRAW WALL THICKNESS */
          /* draw skip to x200 y200
          draw skip dx=-_d_Side * "Wall Thickness" dy="Wall Thickness"  mark x800 y800
          draw skip to x300 y300
          draw skip dx=-_d_Side * "Wall Thickness" dy="Wall Thickness"  mark x801 y801
          draw skip to x600 y600
          draw skip dx=-_d_Side * "Wall Thickness" dy="Wall Thickness"  mark x802 y802
          draw skip to x700 y700
          draw skip dx=-_d_Side * "Wall Thickness" dy=-"Wall Thickness"  mark x803 y803
          draw skip to x800 y800
          draw to x801 y801
          draw to x802 y802
          draw dx=0 dy=-1 to y803
          draw to x803 y803 */
                    
          
          /* PLACE PIPE SYMBOL */
          draw skip to x99 y99
          draw skip dx=_d_Side * _d_PipeOffset dy=0.5             mark x98 y98
          draw cell = XSPIPE
             xs  = _d_PipeScale
             ys  = _d_PipeScale * _d_Ratio
             "Structure Symbology" 
        /* PLACE PIPE LABEL */
        draw skip to x98 y98
        draw skip dx=0 dy=_d_LargestPipe / 2
        _s_LargestPipe = cvt_d_s0(_d_LargestPipe * 12)
        _s_PipeLabel = _s_LargestPipe + ^"^ + " RC PIPE"
        draw text value=_s_PipeLabel "Structure Text Symbology" just=CC
        
        /* PLACE STATION LABEL */
        _s_Station = "STA. " + Drainage Node Station
        draw skip to x98 y98
        draw skip dx=0 dy=-2
        draw text value=_s_Station "Station Text Symbology" just=CT
        
        /**********************************************************************************/            
        /* PLACE STRUCTURE LABEL */
        draw skip to x98 y98
        draw skip dx=0 dy=(_d_DepthOfStructure / 2)+ 8/12
        draw text value = Drainage Node Library Item Name "Structure Text Symbology" just=CC
        draw skip to x98 y98
        draw skip dx=0 dy=(_d_DepthOfStructure / 2)
        draw text value = Drainage Node ID "Structure Text Symbology" just=CC
        draw skip to x98 y98
        draw skip dx=0 dy=(_d_DepthOfStructure / 2)- 8/12
        draw text value = Drainage Node Library Item Description "Structure Text Symbology" just=CC
        /**********************************************************************************/
        
        /* PLACE TOP ELEVATION LABEL */
        set plot parameters "Delimiter Line Symbology"
        draw skip to x705 y705
        draw skip dx=_d_Side * .25 dy=0            mark x706 y706               
        draw dx=_d_Side * 2 dy=0
        draw skip dx=0 dy=.1
        _s_DrainageNodeElevation = "EL. " + cvt_d_s2(_d_DrainageNodeElevation)
        if _d_Side = 1 then 
          {
            draw text value=_s_DrainageNodeElevation "Structure Text Symbology" just=RB
          }
        else
          {
            draw text value=_s_DrainageNodeElevation "Structure Text Symbology" just=LB
          }
        
        /* PLACE BOTTOM INVERT ELEVATION LABEL */
        set plot parameters "Delimiter Line Symbology"
        draw skip to x98 y98
        draw skip dx=_d_Side * (_d_LargestPipe/2) dy=0            
        draw dx=_d_Side * 5 dy=0                                mark x707 y707
        draw skip dx=0 dy=.1
        _s_MinimumInvertElevation = "FL. " + cvt_d_s2(_d_MinimumInvertElevation)
        if _d_Side = 1 then
          {
            draw text value=_s_MinimumInvertElevation "Structure Text Symbology" just=RB
          }
        else
          {
            draw text value=_s_MinimumInvertElevation "Structure Text Symbology" just=LB
          }
        
        /* PLACE DEPTH OF STRUCTURE LABEL */
        set plot parameters "Delimiter Line Symbology"
        draw skip to x705 y705
        draw skip dx=_d_Side * .5 dy=0                 mark x706 y706          
        draw skip to x703 y703
        draw skip dx=_d_Side * .5 dy=0                           
        draw dx=_d_Side * .25 dy=0                              mark x901 y901
        draw dx=_d_Side * .25 dy=0
        draw skip to x901 y901
        /* Draw ArrowHead */
        draw dx=_d_Side * .1 dy=.3
        draw skip to x901 y901
        draw dx=-_d_Side * .1 dy=.3
        draw skip to x901 y901
        draw dx=0 dy=1 to y706                                   mark x900 y900
        /* Draw ArrowHead */
        draw dx=_d_Side * .1 dy=-.3
        draw skip to x900 y900
        draw dx=-_d_Side * .1 dy=-.3
        draw skip to x900 y900
        draw skip dx=_d_Side * .1 dy=(_d_DepthOfStructure / -2)
        _s_DepthOfStructure = cvt_d_s2(_d_DepthOfStructure + .5) + ^'^
        if _d_Side = 1 then
          {
            draw text value=_s_DepthOfStructure "Structure Text Symbology" just=CB angle=270
          }
        else
          {
            draw text value=_s_DepthOfStructure "Structure Text Symbology" just=CB angle=90
          }
          }
          else /* DRAW 10X10 */
          {
            _d_BoxWidth = 10.0
            _d_BoxLength = 10.0
            _d_PipeOffset = _d_BoxWidth / 2

            set plot parameters "Special Structure Symbology"  
            mark x200 y200              
            draw dx=0 dy=-(_d_DepthOfStructure + 0.5) /*depth of structure plus t1*/
            mark x300 y300 mark x99 y99 
            /*mark x400 y400  */                      
            draw dx=_d_Side * _d_BoxWidth dy=0                      mark x500 y500             
            draw dx=0 dy=1 to y200                                  mark x600 y600              
            draw to x200 y200 
            
            /* DRAW WALL THICKNESS 
            draw skip to x200 y200
            draw skip dx=-_d_Side * "Wall Thickness" dy="Wall Thickness"  mark x700 y700
            draw dx=0 dy=-1 to y400
            draw dx=0 dy=-"Wall Thickness"
            draw dx=_d_Side dy=0 to x500
            draw dx=_d_Side * "Wall Thickness" dy=0
            draw dx=0 dy=1 to y700
            draw to x700 y700 */
            
          
            /* PLACE PIPE SYMBOL */
            draw skip to x99 y99
            draw skip dx=_d_Side * _d_PipeOffset dy=0 
            draw skip dx=0 dy=0.5       mark x98 y98
            draw cell = XSPIPE
             xs  = _d_PipeScale
             ys  = _d_PipeScale * _d_Ratio
             "Structure Symbology" 

            /* PLACE STRUCTURE LABEL */
            draw skip to x98 y98
            draw skip dx=0 dy=-1
            _s_BoxWidth = cvt_d_s1(_d_BoxWidth)
            _s_BoxLength = cvt_d_s1(_d_BoxLength)
            _s_const = Drainage Node Library Item Name + " with Mod. Box. Special Design Required"
            draw text value=_s_const "Structure Text Symbology"
        /* PLACE TOP ELEVATION LABEL */
        set plot parameters "Delimiter Line Symbology"
        draw skip to x600 y600
        draw skip dx=_d_Side * .25 dy=0            mark x606 y606               
        draw dx=_d_Side * 2 dy=0
        draw skip dx=0 dy=.1
        _s_DrainageNodeElevation = "EL. " + cvt_d_s2(_d_DrainageNodeElevation)
        if _d_Side = 1 then 
          {
            draw text value=_s_DrainageNodeElevation "Structure Text Symbology" just=RB
          }
        else
          {
            draw text value=_s_DrainageNodeElevation "Structure Text Symbology" just=LB
          }
        
        /* PLACE BOTTOM INVERT ELEVATION LABEL */
        set plot parameters "Delimiter Line Symbology"
        draw skip to x98 y98
        draw skip dx=_d_Side * (_d_LargestPipe/2) dy=0            
        draw dx=_d_Side * (_d_boxwidth/2 + 2) dy=0                                mark x607 y607
        draw skip dx=0 dy=.1
        _s_MinimumInvertElevation = "FL. " + cvt_d_s2(_d_MinimumInvertElevation)
        if _d_Side = 1 then
          {
            draw text value=_s_MinimumInvertElevation "Structure Text Symbology" just=RB
          }
        else
          {
            draw text value=_s_MinimumInvertElevation "Structure Text Symbology" just=LB
          }
        
        /* PLACE DEPTH OF STRUCTURE LABEL */
        set plot parameters "Delimiter Line Symbology"
        draw skip to x600 y600
        draw skip dx=_d_Side * .5 dy=0                 mark x606 y606          
        draw skip to x500 y500
        draw skip dx=_d_Side * .5 dy=0                           
        draw dx=_d_Side * .25 dy=0                              mark x901 y901
        draw dx=_d_Side * .25 dy=0
        draw skip to x901 y901
        /* Draw ArrowHead */
        draw dx=_d_Side * .1 dy=.3
        draw skip to x901 y901
        draw dx=-_d_Side * .1 dy=.3
        draw skip to x901 y901
        draw dx=0 dy=1 to y606                                   mark x900 y900
        /* Draw ArrowHead */
        draw dx=_d_Side * .1 dy=-.3
        draw skip to x900 y900
        draw dx=-_d_Side * .1 dy=-.3
        draw skip to x900 y900
        draw skip dx=_d_Side * .1 dy=(_d_DepthOfStructure / -2)
        _s_DepthOfStructure = cvt_d_s2(_d_DepthOfStructure + .5) + ^'^
        if _d_Side = 1 then
          {
            draw text value=_s_DepthOfStructure "Structure Text Symbology" just=CB angle=270
          }
        else
          {
            draw text value=_s_DepthOfStructure "Structure Text Symbology" just=CB angle=90
          }
          }        
        }
      /* ELSE IF MAXIMUM PIPE SIZE IS 72" */
      else if _d_LargestPipe <= 72/12 then
        {
        _d_D1 = 120/12
        _d_H1 = 100/12
        _d_FSA_Depth = 10/12
        _d_FSA_Width = 140/12
        _d_PipeScale = _d_LargestPipe
        _d_H3 = (_d_DepthOfStructure + 6/12) - (_d_H1 + _d_FSA_Depth + "Wall Thickness")
        
        if _d_H3 >= 1.5 then /* DRAW 4X4 STD + FSA + BASE */
          {
          _d_BoxWidth = 4.0
          _d_BoxLength = 4.0
          _d_PipeOffset = _d_D1 / 2

          set plot parameters "Structure Symbology"         
          draw skip dx=-_d_Side * .5/12 dy=-"Wall Thickness"     mark x200 y200              
          draw dx=0 dy=-_d_H3                                    mark x300 y300              
          draw dx=_d_Side * _d_BoxWidth dy=0                     mark x400 y400              
          draw dx=0 dy=1 to y200                                 mark x500 y500              
          draw to x200 y200                                              
          
          set plot parameters "Structure Wall Symbology"         
          draw dx=0 dy=8/12
          draw dx=_d_side*(_d_BoxWidth + 6/12) dy=0							mark x705 y705
          draw dx=0 dy=-8/12
          draw dx=-_d_side*(6/12) dy =0
          draw skip to x200 y200
          set plot parameters "Structure Symbology"                
          draw skip to x300 y300
          draw dx=-_d_Side * (_d_FSA_Width - _d_BoxWidth)/2 dy=0   mark x600 y600
          draw dx=0 dy=-(_d_FSA_Depth)                             mark x601 y601
          draw dx=_d_Side * _d_FSA_Width dy=0                      mark x602 y602
          draw dx=0 dy=1 to y600                                   mark x603 y603
          draw dx=-_d_Side * (_d_FSA_Width - _d_BoxWidth)/2 dy=0 
        
          draw skip to x300 y300
          draw skip dx=0 dy=-(_d_FSA_Depth)         
          draw skip dx=-_d_Side * (_d_D1 - _d_BoxWidth)/2 dy=0   mark x700 y700
          draw dx=0 dy=-(_d_H1)                                  mark x701 y701 mark x99 y99
          draw dx=_d_Side * _d_D1 dy=0                           mark x703 y703
          draw dx=0 dy=1 to y700                                 mark x704 y704
          
          set plot parameters "Structure Wall Symbology"  
          draw skip to x701 y701
          draw dx=-_d_side*0.5 dy=0
          draw dx=0 dy=-0.5
          draw dx=_d_side*(_d_D1 + 1) dy=0
          draw dx=0 dy =0.5
          draw to x703 y703
                    
          /* DRAW WALL THICKNESS */
          /* draw skip to x200 y200
          draw skip dx=-_d_Side * "Wall Thickness" dy="Wall Thickness"  mark x800 y800
          draw skip to x300 y300
          draw skip dx=-_d_Side * "Wall Thickness" dy="Wall Thickness"  mark x801 y801
          draw skip to x600 y600
          draw skip dx=-_d_Side * "Wall Thickness" dy="Wall Thickness"  mark x802 y802
          draw skip to x700 y700
          draw skip dx=-_d_Side * "Wall Thickness" dy=-"Wall Thickness"  mark x803 y803
          draw skip to x800 y800
          draw to x801 y801
          draw to x802 y802
          draw dx=0 dy=-1 to y803
          draw to x803 y803 */
                    
          
          /* PLACE PIPE SYMBOL */
          draw skip to x99 y99
          draw skip dx=_d_Side * _d_PipeOffset dy=0.5             mark x98 y98
          draw cell = XSPIPE
             xs  = _d_PipeScale
             ys  = _d_PipeScale * _d_Ratio
             "Structure Symbology" 
        /* PLACE PIPE LABEL */
        draw skip to x98 y98
        draw skip dx=0 dy=_d_LargestPipe / 2
        _s_LargestPipe = cvt_d_s0(_d_LargestPipe * 12)
        _s_PipeLabel = _s_LargestPipe + ^"^ + " RC PIPE"
        draw text value=_s_PipeLabel "Structure Text Symbology" just=CC
        
        /* PLACE STATION LABEL */
        _s_Station = "STA. " + Drainage Node Station
        draw skip to x98 y98
        draw skip dx=0 dy=-2
        draw text value=_s_Station "Station Text Symbology" just=CT
        
        /**********************************************************************************/            
        /* PLACE STRUCTURE LABEL */
        draw skip to x98 y98
        draw skip dx=0 dy=(_d_DepthOfStructure / 2)+ 8/12
        draw text value = Drainage Node Library Item Name "Structure Text Symbology" just=CC
        draw skip to x98 y98
        draw skip dx=0 dy=(_d_DepthOfStructure / 2)
        draw text value = Drainage Node ID "Structure Text Symbology" just=CC
        draw skip to x98 y98
        draw skip dx=0 dy=(_d_DepthOfStructure / 2)- 8/12
        draw text value = Drainage Node Library Item Description "Structure Text Symbology" just=CC
        /**********************************************************************************/
        
        /* PLACE TOP ELEVATION LABEL */
        set plot parameters "Delimiter Line Symbology"
        draw skip to x705 y705
        draw skip dx=_d_Side * .25 dy=0            mark x706 y706               
        draw dx=_d_Side * 2 dy=0
        draw skip dx=0 dy=.1
        _s_DrainageNodeElevation = "EL. " + cvt_d_s2(_d_DrainageNodeElevation)
        if _d_Side = 1 then 
          {
            draw text value=_s_DrainageNodeElevation "Structure Text Symbology" just=RB
          }
        else
          {
            draw text value=_s_DrainageNodeElevation "Structure Text Symbology" just=LB
          }
        
        /* PLACE BOTTOM INVERT ELEVATION LABEL */
        set plot parameters "Delimiter Line Symbology"
        draw skip to x98 y98
        draw skip dx=_d_Side * (_d_LargestPipe/2) dy=0            
        draw dx=_d_Side * 5 dy=0                                mark x707 y707
        draw skip dx=0 dy=.1
        _s_MinimumInvertElevation = "FL. " + cvt_d_s2(_d_MinimumInvertElevation)
        if _d_Side = 1 then
          {
            draw text value=_s_MinimumInvertElevation "Structure Text Symbology" just=RB
          }
        else
          {
            draw text value=_s_MinimumInvertElevation "Structure Text Symbology" just=LB
          }
        
        /* PLACE DEPTH OF STRUCTURE LABEL */
        set plot parameters "Delimiter Line Symbology"
        draw skip to x705 y705
        draw skip dx=_d_Side * .5 dy=0                 mark x706 y706          
        draw skip to x703 y703
        draw skip dx=_d_Side * .5 dy=0                           
        draw dx=_d_Side * .25 dy=0                              mark x901 y901
        draw dx=_d_Side * .25 dy=0
        draw skip to x901 y901
        /* Draw ArrowHead */
        draw dx=_d_Side * .1 dy=.3
        draw skip to x901 y901
        draw dx=-_d_Side * .1 dy=.3
        draw skip to x901 y901
        draw dx=0 dy=1 to y706                                   mark x900 y900
        /* Draw ArrowHead */
        draw dx=_d_Side * .1 dy=-.3
        draw skip to x900 y900
        draw dx=-_d_Side * .1 dy=-.3
        draw skip to x900 y900
        draw skip dx=_d_Side * .1 dy=(_d_DepthOfStructure / -2)
        _s_DepthOfStructure = cvt_d_s2(_d_DepthOfStructure + .5) + ^'^
        if _d_Side = 1 then
          {
            draw text value=_s_DepthOfStructure "Structure Text Symbology" just=CB angle=270
          }
        else
          {
            draw text value=_s_DepthOfStructure "Structure Text Symbology" just=CB angle=90
          }
          }
          else /* DRAW 10X10 */
          {
            _d_BoxWidth = 10.0
            _d_BoxLength = 10.0
            _d_PipeOffset = _d_BoxWidth / 2

            set plot parameters "Special Structure Symbology"  
            mark x200 y200              
            draw dx=0 dy=-(_d_DepthOfStructure + 0.5) /*depth of structure plus t1*/
            mark x300 y300 mark x99 y99 
            /*mark x400 y400  */                      
            draw dx=_d_Side * _d_BoxWidth dy=0                      mark x500 y500             
            draw dx=0 dy=1 to y200                                  mark x600 y600              
            draw to x200 y200 
            
            /* DRAW WALL THICKNESS 
            draw skip to x200 y200
            draw skip dx=-_d_Side * "Wall Thickness" dy="Wall Thickness"  mark x700 y700
            draw dx=0 dy=-1 to y400
            draw dx=0 dy=-"Wall Thickness"
            draw dx=_d_Side dy=0 to x500
            draw dx=_d_Side * "Wall Thickness" dy=0
            draw dx=0 dy=1 to y700
            draw to x700 y700 */
            
          
            /* PLACE PIPE SYMBOL */
            draw skip to x99 y99
            draw skip dx=_d_Side * _d_PipeOffset dy=0 
            draw skip dx=0 dy=0.5       mark x98 y98
            draw cell = XSPIPE
             xs  = _d_PipeScale
             ys  = _d_PipeScale * _d_Ratio
             "Structure Symbology" 

            /* PLACE STRUCTURE LABEL */
            draw skip to x98 y98
            draw skip dx=0 dy=-1
            _s_BoxWidth = cvt_d_s1(_d_BoxWidth)
            _s_BoxLength = cvt_d_s1(_d_BoxLength)
            _s_const = Drainage Node Library Item Name + " with Mod. Box. Special Design Required"
            draw text value=_s_const "Structure Text Symbology"
        /* PLACE TOP ELEVATION LABEL */
        set plot parameters "Delimiter Line Symbology"
        draw skip to x600 y600
        draw skip dx=_d_Side * .25 dy=0            mark x606 y606               
        draw dx=_d_Side * 2 dy=0
        draw skip dx=0 dy=.1
        _s_DrainageNodeElevation = "EL. " + cvt_d_s2(_d_DrainageNodeElevation)
        if _d_Side = 1 then 
          {
            draw text value=_s_DrainageNodeElevation "Structure Text Symbology" just=RB
          }
        else
          {
            draw text value=_s_DrainageNodeElevation "Structure Text Symbology" just=LB
          }
        
        /* PLACE BOTTOM INVERT ELEVATION LABEL */
        set plot parameters "Delimiter Line Symbology"
        draw skip to x98 y98
        draw skip dx=_d_Side * (_d_LargestPipe/2) dy=0            
        draw dx=_d_Side * (_d_boxwidth/2 + 2) dy=0                                mark x607 y607
        draw skip dx=0 dy=.1
        _s_MinimumInvertElevation = "FL. " + cvt_d_s2(_d_MinimumInvertElevation)
        if _d_Side = 1 then
          {
            draw text value=_s_MinimumInvertElevation "Structure Text Symbology" just=RB
          }
        else
          {
            draw text value=_s_MinimumInvertElevation "Structure Text Symbology" just=LB
          }
        
        /* PLACE DEPTH OF STRUCTURE LABEL */
        set plot parameters "Delimiter Line Symbology"
        draw skip to x600 y600
        draw skip dx=_d_Side * .5 dy=0                 mark x606 y606          
        draw skip to x500 y500
        draw skip dx=_d_Side * .5 dy=0                           
        draw dx=_d_Side * .25 dy=0                              mark x901 y901
        draw dx=_d_Side * .25 dy=0
        draw skip to x901 y901
        /* Draw ArrowHead */
        draw dx=_d_Side * .1 dy=.3
        draw skip to x901 y901
        draw dx=-_d_Side * .1 dy=.3
        draw skip to x901 y901
        draw dx=0 dy=1 to y606                                   mark x900 y900
        /* Draw ArrowHead */
        draw dx=_d_Side * .1 dy=-.3
        draw skip to x900 y900
        draw dx=-_d_Side * .1 dy=-.3
        draw skip to x900 y900
        draw skip dx=_d_Side * .1 dy=(_d_DepthOfStructure / -2)
        _s_DepthOfStructure = cvt_d_s2(_d_DepthOfStructure + .5) + ^'^
        if _d_Side = 1 then
          {
            draw text value=_s_DepthOfStructure "Structure Text Symbology" just=CB angle=270
          }
        else
          {
            draw text value=_s_DepthOfStructure "Structure Text Symbology" just=CB angle=90
          }
          }        
        }
      /* ELSE IF MAXIMUM PIPE SIZE > 72" THEN CUSTOM STRUCTURES REQUIRED */
      else if _d_LargestPipe > 72/12 then
        {
            _d_BoxWidth = 10.0
            _d_BoxLength = 10.0
            _d_PipeScale = _d_LargestPipe
            _d_PipeOffset = _d_BoxWidth / 2

            draw skip dx=-_d_Side * .5/12 dy=-"Wall Thickness"     mark x200 y200              
            draw dx=0 dy=-(_d_DepthOfStructure - "Wall Thickness") mark x300 y300 mark x99 y99 
            draw dx=0 dy=-6/12                                     mark x400 y400                        
            draw dx=_d_Side * _d_BoxWidth dy=0                     mark x500 y500              
            draw dx=0 dy=1 to y200                                 mark x600 y600              
            draw to x200 y200 
            
            /* DRAW WALL THICKNESS */
            draw skip to x200 y200
            draw skip dx=-_d_Side * "Wall Thickness" dy="Wall Thickness"  mark x700 y700
            draw dx=0 dy=-1 to y400
            draw dx=0 dy=-"Wall Thickness"
            draw dx=_d_Side dy=0 to x500
            draw dx=_d_Side * "Wall Thickness" dy=0
            draw dx=0 dy=1 to y700
            draw to x700 y700
            
          
            /* PLACE PIPE SYMBOL */
            draw skip to x99 y99
            draw skip dx=_d_Side * _d_PipeOffset dy=0        mark x98 y98 
            draw cell = XSPIPE
             xs  = _d_PipeScale
             ys  = _d_PipeScale * _d_Ratio
             "Structure Symbology" 

            /* PLACE STRUCTURE LABEL */
            draw skip to x98 y98
            draw skip dx=0 dy=-2
            draw text value=Drainage Node ID "Structure Text Symbology" 
            draw skip dx=0 dy=-2
            _s_BoxWidth = cvt_d_s1(_d_BoxWidth)
            _s_BoxLength = cvt_d_s1(_d_BoxLength)
            _s_const = "Special Drainage Box Design Required"
            draw text value=_s_const "Structure Text Symbology"
            draw skip dx=0 dy=-2
            _d_fl = Drainage Node Minimum Invert Elevation
            _s_fl = "FL " + cvt_d_s2(_d_fl)
            draw text value=_s_fl "Structure Text Symbology" 
            draw skip dx=0 dy=-2
            _s_LargestPipe = cvt_d_s0(_d_LargestPipe * 12)
            _s_PipeLabel = _s_LargestPipe + ^" Pipe^
            draw text value=_s_PipeLabel "Structure Text Symbology" 
        } 
    }
    else if _d_DepthOfStructure > 12 then
    {
      /* IF MAXIMUM PIPE SIZE <= 24" */
      if _d_LargestPipe <= 24/12 then
        {
        _d_BoxWidth = 48/12
        _d_BoxDepth = 72/12
        _d_BaseWidth = 48/12
        _d_BaseDepth = 48/12
        _d_FSA_Depth = 6/12
        _d_FSA_Width = 64/12
        _d_RiserDepth = (_d_DepthOfStructure + 6/12) - (_d_BaseDepth + _d_FSA_Depth + _d_BoxDepth + "Wall Thickness")
        _d_RiserWidth = 48/12
        _d_PipeScale = _d_LargestPipe
        _d_PipeOffset = _d_BoxWidth / 2
        
        /* IF RISER REQUIRED */
        if _d_RiserDepth >= 2 then
          {   
          /* DRAW STANDARD BOX 4X4X6 */  
          draw skip dx=-_d_Side * .5/12 dy=-"Wall Thickness"     mark x200 y200              
          draw dx=0 dy=-_d_BoxDepth                              mark x300 y300              
          draw dx=_d_Side * _d_BoxWidth dy=0                     mark x400 y400              
          draw dx=0 dy=1 to y200                                 mark x500 y500              
          draw to x200 y200                                              
         
          /* DRAW FLAT SLAB ADAPTOR */
          draw skip to x300 y300
          draw dx=-_d_Side * (_d_FSA_Width - _d_BoxWidth)/2 dy=0   mark x600 y600
          draw dx=0 dy=-(_d_FSA_Depth)                             mark x601 y601
          draw dx=_d_Side * _d_FSA_Width dy=0                      mark x602 y602
          draw dx=0 dy=1 to y600                                   mark x603 y603
          draw dx=-_d_Side * (_d_FSA_Width - _d_BoxWidth)/2 dy=0
          
          /* DRAW RISER */
          draw skip to x300 y300
          draw skip dx=0 dy=-_d_FSA_Depth                          mark x700 y700
          draw dx=0 dy=-_d_RiserDepth                              mark x701 y701
          draw dx=_d_Side * _d_RiserWidth dy=0                     mark x702 y702
          draw dx=0 dy=1 to y700                                   mark x703 y703
          
          /* DRAW BASE */
          draw skip to x701 y701
          draw dx=0 dy=-_d_BaseDepth                               mark x800 y800 mark x99 y99
          draw dx=_d_Side * _d_BaseWidth dy=0                      mark x801 y801
          draw to x702 y702
          
          /* PLACE PIPE SYMBOL */
          draw skip to x99 y99
          draw skip dx=_d_Side * _d_PipeOffset dy=0.5              mark x98 y98 
          draw cell = XSPIPE
             xs  = _d_PipeScale
             ys  = _d_PipeScale * _d_Ratio
             "Structure Symbology" 

          /* PLACE STRUCTURE LABEL */
          draw skip to x98 y98
          draw skip dx=0 dy=-2
          draw text value=Drainage Node ID "Structure Text Symbology" 
          draw skip dx=0 dy=-2
          _s_BoxWidth = cvt_d_s1(_d_BoxWidth)
          _s_BoxLength = cvt_d_s1(_d_BoxLength)
          _s_const = "Special Drainage Box Design Required"
          draw text value=_s_const "Structure Text Symbology"
          draw skip dx=0 dy=-2
          _d_fl = Drainage Node Minimum Invert Elevation
          _s_fl = "FL " + cvt_d_s2(_d_fl)
          draw text value=_s_fl "Structure Text Symbology" 
          draw skip dx=0 dy=-2
          _s_LargestPipe = cvt_d_s0(_d_LargestPipe * 12)
          _s_PipeLabel = _s_LargestPipe + ^" Pipe^
          draw text value=_s_PipeLabel "Structure Text Symbology"  
          }
        /* ELSE DRAW THE STRUCTURE WITHOUT THE RISER */
        else
          {
          /* DRAW STANDARD BOX 4X4X6 */  
          draw skip dx=-_d_Side * .5/12 dy=-"Wall Thickness"     mark x200 y200              
          draw dx=0 dy=-_d_BoxDepth                              mark x300 y300              
          draw dx=_d_Side * _d_BoxWidth dy=0                     mark x400 y400              
          draw dx=0 dy=1 to y200                                 mark x500 y500              
          draw to x200 y200                                              
         
          /* DRAW FLAT SLAB ADAPTOR */
          draw skip to x300 y300
          draw dx=-_d_Side * (_d_FSA_Width - _d_BoxWidth)/2 dy=0   mark x600 y600
          draw dx=0 dy=-(_d_FSA_Depth)                             mark x601 y601
          draw dx=_d_Side * _d_FSA_Width dy=0                      mark x602 y602
          draw dx=0 dy=1 to y600                                   mark x603 y603
          draw dx=-_d_Side * (_d_FSA_Width - _d_BoxWidth)/2 dy=0
          
          /* DRAW BASE */
          draw skip to x300 y300
          draw skip dx=0 dy=-_d_FSA_Depth                          mark x700 y700
          draw dx=0 dy=-(_d_RiserDepth + _d_BaseDepth)             mark x701 y701 mark x99 y99
          draw dx=_d_Side * _d_BaseWidth dy=0                      mark x702 y702
          draw dx=0 dy=1 to y700                                   mark x703 y703
          
          /* PLACE PIPE SYMBOL */
          draw skip to x99 y99
          draw skip dx=_d_Side * _d_PipeOffset dy=0.5              mark x98 y98 
          draw cell = XSPIPE
             xs  = _d_PipeScale
             ys  = _d_PipeScale * _d_Ratio
             "Structure Symbology" 

          /* PLACE STRUCTURE LABEL */
          draw skip to x98 y98
          draw skip dx=0 dy=-2
          draw text value=Drainage Node ID "Structure Text Symbology" 
          draw skip dx=0 dy=-2
          _s_BoxWidth = cvt_d_s1(_d_BoxWidth)
          _s_BoxLength = cvt_d_s1(_d_BoxLength)
          _s_const = "Special Drainage Box Design Required"
          draw text value=_s_const "Structure Text Symbology"
          draw skip dx=0 dy=-2
          _d_fl = Drainage Node Minimum Invert Elevation
          _s_fl = "FL " + cvt_d_s2(_d_fl)
          draw text value=_s_fl "Structure Text Symbology" 
          draw skip dx=0 dy=-2
          _s_LargestPipe = cvt_d_s0(_d_LargestPipe * 12)
          _s_PipeLabel = _s_LargestPipe + ^" Pipe^
          draw text value=_s_PipeLabel "Structure Text Symbology"
          }
        }
    } 

   }
 /* ELSE THE SIZE OF THE PIPE WAS NOT ABLE TO BE DETERMINED */
 else
   {
     draw skip to Drainage Component Front Point 
     draw text char=^Unable to calculate box dimensions^ "Structure Text Symbology"
   }
}
end subroutine







